@@ -134,13 +134,18 @@ def get_length(arg):
         base_length = 2 # brackets
         total_length = base_length + get_length(arg.value) + get_length(arg.slice)
         return total_length
-    if isinstance(arg, astroid.nodes.JoinedStr) or isinstance(arg, astroid.nodes.FormattedValue):
+    if isinstance(arg, astroid.nodes.JoinedStr):
         base_length = 3 # quotes and 'f'
         total_length = 0
         for value in arg.values:
             total_length += get_length(value)
         total_length += base_length
         return total_length
+    if isinstance(arg, astroid.nodes.FormattedValue):
+        base_length = 3 # quotes and 'f'
+        total_length = 0
+        total_length += base_length + get_length(arg.value)
+        return total_length
     if isinstance(arg, astroid.nodes.Starred):
         base_length = 1 # '*'
         total_length = get_length(arg.value)
@@ -174,5 +179,7 @@ def get_length(arg):
         total_length = len(arg.operand)
         total_length += base_length
         return total_length
+    if isinstance(arg, None):
+        return 0
     print(f"Unhandled {arg}")
     return 0
